@@ -17,4 +17,8 @@ def download(url, enhance=False):
     return False
 
 def __enhance_articles(articles):
-    return JarticleEnhancer.RUN(articles=articles, saveToDB=False, returnArticles=True)
\ No newline at end of file
+    return JarticleEnhancer.RUN(articles=articles, saveToDB=False, returnArticles=True)
+
+if __name__ == '__main__':
+    test = download("https://www.nbcnews.com/politics/justice-department/justice-department-investigating-trumps-actions-part-jan-6-probe-rcna40167")
+    print(test)
\ No newline at end of file
