@@ -2,14 +2,11 @@ from FSON import DICT
 from fairNLP import Language
 from JEngines import JarticleEnhancer
 
-from Jarticle.jProvider import jPro
 from FLog.LOGGER import Log
 Log = Log("Jarticle.Engine.Processor.ArticleProcessor_v2")
 
 LAST_UPDATE = "May 19 2022"
 
-JP = jPro()
-
 # -> Master Runner of Single Article
 def process_article(article, isUpdate):
     updated_date = DICT.get("updatedDate", article, False)
@@ -26,9 +23,4 @@ def process_article(article, isUpdate):
     content = Language.combine_args_str(title, body, description)
     # -> Enhancers
     enhanced_article = JarticleEnhancer.enhance_article(article=article, content=content)
-    # -> Update Article in MongoDB
-    JP.update_article(enhanced_article)
-
-
-if __name__ == '__main__':
-    RUN()
\ No newline at end of file
+    return enhanced_article
\ No newline at end of file
